@@ -1,18 +1,9 @@
-import sys
-import warnings
-from typing import TYPE_CHECKING, List, Dict
+from __future__ import annotations
+
+from typing import Protocol
+
 from distutils.command.build import build as _build
 
-from setuptools import SetuptoolsDeprecationWarning
-
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-elif TYPE_CHECKING:
-    from typing_extensions import Protocol
-else:
-    from abc import ABC as Protocol
-
-
 _ORIGINAL_SUBCOMMANDS = {"build_py", "build_clib", "build_ext", "build_scripts"}
 
 
@@ -20,18 +11,6 @@ class build(_build):
     # copy to avoid sharing the object with parent class
     sub_commands = _build.sub_commands[:]
 
-    def get_sub_commands(self):
-        subcommands = {cmd[0] for cmd in _build.sub_commands}
-        if subcommands - _ORIGINAL_SUBCOMMANDS:
-            msg = """
-            It seems that you are using `distutils.command.build` to add
-            new subcommands. Using `distutils` directly is considered deprecated,
-            please use `setuptools.command.build`.
-            """
-            warnings.warn(msg, SetuptoolsDeprecationWarning)
-            self.sub_commands = _build.sub_commands
-        return super().get_sub_commands()
-
 
 class SubCommand(Protocol):
     """In order to support editable installations (see :pep:`660`) all
@@ -111,7 +90,7 @@ class SubCommand(Protocol):
     def run(self):
         """(Required by the original :class:`setuptools.Command` interface)"""
 
-    def get_source_files(self) -> List[str]:
+    def get_source_files(self) -> list[str]:
         """
         Return a list of all files that are used by the command to create the expected
         outputs.
@@ -122,7 +101,7 @@ class SubCommand(Protocol):
         All files should be strings relative to the project root directory.
         """
 
-    def get_outputs(self) -> List[str]:
+    def get_outputs(self) -> list[str]:
         """
         Return a list of files intended for distribution as they would have been
         produced by the build.
@@ -135,7 +114,7 @@ class SubCommand(Protocol):
            and don't correspond to any source file already present in the project.
         """
 
-    def get_output_mapping(self) -> Dict[str, str]:
+    def get_output_mapping(self) -> dict[str, str]:
         """
         Return a mapping between destination files as they would be produced by the
         build (dict keys) into the respective existing (source) files (dict values).
