@@ -1,27 +1,27 @@
-import os
-import sys
-import tempfile
-import operator
+from __future__ import annotations
+
+import builtins
+import contextlib
 import functools
 import itertools
-import re
-import contextlib
+import operator
+import os
 import pickle
+import re
+import sys
+import tempfile
 import textwrap
-import builtins
+from abc import ABC
 
 import pkg_resources
-from distutils.errors import DistutilsError
 from pkg_resources import working_set
 
+from distutils.errors import DistutilsError
+
 if sys.platform.startswith('java'):
     import org.python.modules.posix.PosixModule as _os
 else:
     _os = sys.modules[os.name]
-try:
-    _file = file
-except NameError:
-    _file = None
 _open = open
 
 
@@ -263,7 +263,7 @@ def run_setup(setup_script, args):
             # Normal exit, just return
 
 
-class AbstractSandbox:
+class AbstractSandbox(ABC):
     """Wrap 'os' module and 'open()' builtin for virtualizing setup scripts"""
 
     _active = False
@@ -281,15 +281,11 @@ class AbstractSandbox:
 
     def __enter__(self):
         self._copy(self)
-        if _file:
-            builtins.file = self._file
         builtins.open = self._open
         self._active = True
 
     def __exit__(self, exc_type, exc_value, traceback):
         self._active = False
-        if _file:
-            builtins.file = _file
         builtins.open = _open
         self._copy(_os)
 
@@ -298,7 +294,7 @@ class AbstractSandbox:
         with self:
             return func()
 
-    def _mk_dual_path_wrapper(name):
+    def _mk_dual_path_wrapper(name: str):  # type: ignore[misc] # https://github.com/pypa/setuptools/pull/4099
         original = getattr(_os, name)
 
         def wrap(self, src, dst, *args, **kw):
@@ -308,11 +304,11 @@ class AbstractSandbox:
 
         return wrap
 
-    for name in ["rename", "link", "symlink"]:
-        if hasattr(_os, name):
-            locals()[name] = _mk_dual_path_wrapper(name)
+    for __name in ["rename", "link", "symlink"]:
+        if hasattr(_os, __name):
+            locals()[__name] = _mk_dual_path_wrapper(__name)
 
-    def _mk_single_path_wrapper(name, original=None):
+    def _mk_single_path_wrapper(name: str, original=None):  # type: ignore[misc] # https://github.com/pypa/setuptools/pull/4099
         original = original or getattr(_os, name)
 
         def wrap(self, path, *args, **kw):
@@ -322,10 +318,8 @@ class AbstractSandbox:
 
         return wrap
 
-    if _file:
-        _file = _mk_single_path_wrapper('file', _file)
     _open = _mk_single_path_wrapper('open', _open)
-    for name in [
+    for __name in [
         "stat",
         "listdir",
         "chdir",
@@ -346,10 +340,10 @@ class AbstractSandbox:
         "pathconf",
         "access",
     ]:
-        if hasattr(_os, name):
-            locals()[name] = _mk_single_path_wrapper(name)
+        if hasattr(_os, __name):
+            locals()[__name] = _mk_single_path_wrapper(__name)
 
-    def _mk_single_with_return(name):
+    def _mk_single_with_return(name: str):  # type: ignore[misc] # https://github.com/pypa/setuptools/pull/4099
         original = getattr(_os, name)
 
         def wrap(self, path, *args, **kw):
@@ -360,11 +354,11 @@ class AbstractSandbox:
 
         return wrap
 
-    for name in ['readlink', 'tempnam']:
-        if hasattr(_os, name):
-            locals()[name] = _mk_single_with_return(name)
+    for __name in ['readlink', 'tempnam']:
+        if hasattr(_os, __name):
+            locals()[__name] = _mk_single_with_return(__name)
 
-    def _mk_query(name):
+    def _mk_query(name: str):  # type: ignore[misc] # https://github.com/pypa/setuptools/pull/4099
         original = getattr(_os, name)
 
         def wrap(self, *args, **kw):
@@ -375,9 +369,9 @@ class AbstractSandbox:
 
         return wrap
 
-    for name in ['getcwd', 'tmpnam']:
-        if hasattr(_os, name):
-            locals()[name] = _mk_query(name)
+    for __name in ['getcwd', 'tmpnam']:
+        if hasattr(_os, __name):
+            locals()[__name] = _mk_query(__name)
 
     def _validate_path(self, path):
         """Called to remap or validate any path, whether input or output"""
@@ -424,7 +418,7 @@ class DirectorySandbox(AbstractSandbox):
         "tempnam",
     ])
 
-    _exception_patterns = []
+    _exception_patterns: list[str | re.Pattern] = []
     "exempt writing to paths that match the pattern"
 
     def __init__(self, sandbox, exceptions=_EXCEPTIONS):
@@ -440,13 +434,6 @@ class DirectorySandbox(AbstractSandbox):
 
         raise SandboxViolation(operation, args, kw)
 
-    if _file:
-
-        def _file(self, path, mode='r', *args, **kw):
-            if mode not in ('r', 'rt', 'rb', 'rU', 'U') and not self._ok(path):
-                self._violation("file", path, mode, *args, **kw)
-            return _file(path, mode, *args, **kw)
-
     def _open(self, path, mode='r', *args, **kw):
         if mode not in ('r', 'rt', 'rb', 'rU', 'U') and not self._ok(path):
             self._violation("open", path, mode, *args, **kw)
